<!-- SPDX-FileCopyrightText: 2025 Semiotic AI, Inc. -->
<!-- SPDX-License-Identifier: MIT -->

# Native Functions

Low-level cryptographic operations powered by Rust.

## JWT Operations

::: agentium_sdk.verify_jwt

::: agentium_sdk.parse_jwt_header

## DID Operations

::: agentium_sdk.extract_public_key_jwk

## Key Generation

::: agentium_sdk.generate_keypair

::: agentium_sdk.get_public_key

## Wallet Authentication

::: agentium_sdk.sign_challenge

::: agentium_sdk.validate_caip2

## Telemetry

::: agentium_sdk.init_tracing

## Native Types

::: agentium_sdk.VerificationResult

::: agentium_sdk.VerificationError

::: agentium_sdk.JwtHeader

::: agentium_sdk.GeneratedKeyPair
